@@ -101,7 +101,7 @@ bool AI :: ServiceOrder :: completelyFailed ()
 }
 
 
-int AI::ServiceOrder::possible ( pvehicle supplier )
+int AI::ServiceOrder::possible ( Vehicle* supplier )
 {
    if ( !ai->getMap()->getField( getTargetUnit()->getPosition())->unitHere ( getTargetUnit() ))
      return 0;
@@ -165,9 +165,9 @@ int AI::ServiceOrder::possible ( pvehicle supplier )
 }
 
 
-bool AI::ServiceOrder::execute1st ( pvehicle supplier )
+bool AI::ServiceOrder::execute1st ( Vehicle* supplier )
 {
-   pvehicle targ = getTargetUnit();
+   Vehicle* targ = getTargetUnit();
    MapCoordinate3D meet;
 
    vector<MapCoordinate3D> dest;
@@ -177,7 +177,7 @@ bool AI::ServiceOrder::execute1st ( pvehicle supplier )
              int x = targ->xpos;
              int y = targ->ypos;
              getnextfield ( x, y, i );
-             pfield fld = getfield ( x, y );
+             tfield* fld = getfield ( x, y );
              if ( fld && fieldAccessible ( fld, supplier, 1<<h ) == 2 && !fld->building && !fld->vehicle ) {
                 bool result = false;
                 TemporaryContainerStorage tus ( supplier );
@@ -233,7 +233,7 @@ bool AI::ServiceOrder::execute1st ( pvehicle supplier )
    return false;
 }
 
-void AI::ServiceOrder::setServiceUnit ( pvehicle veh )
+void AI::ServiceOrder::setServiceUnit ( Vehicle* veh )
 {
    if ( veh )
       serviceUnitID = veh->networkid;
@@ -243,7 +243,7 @@ void AI::ServiceOrder::setServiceUnit ( pvehicle veh )
 
 void AI::ServiceOrder::releaseServiceUnit ( ServiceOrder& so )
 {
-   pvehicle veh = so.getServiceUnit();
+   Vehicle* veh = so.getServiceUnit();
    if ( veh ) {
       so.setServiceUnit ( NULL );
       veh->aiparam[so.ai->getPlayerNum()]->resetTask();
@@ -293,7 +293,7 @@ bool AI::ServiceOrder::valid (  ) const
    switch ( requiredService ) {
       case VehicleService::srv_repair     : return getTargetUnit()->damage > 0;
       case VehicleService::srv_ammo       : return getTargetUnit()->ammo[position] < getTargetUnit()->typ->weapons.weapon[position].count;
-      case VehicleService::srv_resource   : return getTargetUnit()->getResource(getTargetUnit()->typ->tank.resource(position), position, 1) < getTargetUnit()->typ->tank.resource(position);
+      case VehicleService::srv_resource   : return getTargetUnit()->getResource(getTargetUnit()->getStorageCapacity().resource(position), position, 1) < getTargetUnit()->getStorageCapacity().resource(position);
       default: return false;
    }
 }
@@ -320,7 +320,7 @@ bool AI::ServiceOrder::operator!=( const ServiceOrder& so ) const
 AI :: ServiceOrder :: ~ServiceOrder (  )
 {
    if ( active ) {
-      pvehicle serv = getServiceUnit();
+      Vehicle* serv = getServiceUnit();
       if ( serv )
          serv->aiparam[ai->getPlayerNum()]->resetTask();
    }
@@ -347,14 +347,14 @@ void AI :: issueServices ( )
    serviceOrders.erase ( remove_if ( serviceOrders.begin(), serviceOrders.end(), ServiceOrder::targetDestroyed ), serviceOrders.end());
 
    for ( Player::VehicleList::iterator vi = getPlayer().vehicleList.begin(); vi != getPlayer().vehicleList.end(); vi++ ) {
-      pvehicle veh = *vi;
+      Vehicle* veh = *vi;
       if ( getMap()->getField( veh->getPosition() )->unitHere( veh )) {
          if ( veh->damage > config.damageLimit )
             issueService ( VehicleService::srv_repair, veh->networkid ) ;
 
          for ( int i = 0; i< resourceTypeNum; i++ )
             if ( veh->maxMovement() ) // stationary units are ignored
-               if ( veh->getResource(maxint, i, 1) < veh->typ->tank.resource(i) * config.resourceLimit.resource(i) / 100 )
+               if ( veh->getResource(maxint, i, 1) < veh->getStorageCapacity().resource(i) * config.resourceLimit.resource(i) / 100 )
                   issueService ( VehicleService::srv_resource, veh->networkid, i);
 
          for ( int w = 0; w< veh->typ->weapons.count; w++ )
@@ -365,7 +365,7 @@ void AI :: issueServices ( )
    }
 }
 
-AI::ServiceOrder& AI :: issueRefuelOrder ( pvehicle veh, bool returnImmediately )
+AI::ServiceOrder& AI :: issueRefuelOrder ( Vehicle* veh, bool returnImmediately )
 {
    ServiceOrder& so = issueService ( VehicleService::srv_resource, veh->networkid, Resources::Fuel);
    if ( returnImmediately ) {
@@ -387,7 +387,7 @@ AI::ServiceOrder& AI :: issueRefuelOrder ( pvehicle veh, bool returnImmediately
 
 MapCoordinate3D AI :: findServiceBuilding ( const ServiceOrder& so, int* distance )
 {
-   pvehicle veh = so.getTargetUnit();
+   Vehicle* veh = so.getTargetUnit();
    if ( getMap()->getField( veh->getPosition())->unitHere ( veh ))
       if ( !veh->canMove() )
          return MapCoordinate3D ( -1, -1, 1 );
@@ -405,16 +405,16 @@ MapCoordinate3D AI :: findServiceBuilding ( const ServiceOrder& so, int* distanc
    AStar3D astar ( getMap(), veh, true, maxMovement*10 );
    astar.findAllAccessibleFields ( );
 
-   pbuilding bestBuilding = NULL;
+   Building* bestBuilding = NULL;
    int bestDistance = maxint;
    MapCoordinate3D bestPos;
 
-   pbuilding bestBuilding_p = NULL;
+   Building* bestBuilding_p = NULL;
    int bestDistance_p = maxint;
    MapCoordinate3D bestPos_p;
 
    for ( Player::BuildingList::iterator bi = getPlayer().buildingList.begin(); bi != getPlayer().buildingList.end(); bi++ ) {
-      pbuilding bld = *bi;
+      Building* bld = *bi;
       if ( astar.getFieldAccess( bld->getEntry())  ) { // ####TRANS
          MapCoordinate3D buildingPos = bld->getEntry();
          buildingPos.setnum ( buildingPos.x, buildingPos.y, -1 );
@@ -439,7 +439,7 @@ MapCoordinate3D AI :: findServiceBuilding ( const ServiceOrder& so, int* distanc
                                                  }
                                                  break;
                case VehicleService::srv_resource:  {
-                                                     Resources needed =  veh->typ->tank - veh->getResource(Resources(maxint,maxint,maxint), true);
+                                                     Resources needed =  veh->getStorageCapacity() - veh->getResource(Resources(maxint,maxint,maxint), true);
                                                      Resources avail = bld->getResource ( needed, 1 );
                                                      if ( avail < needed )
                                                         avail += bld->netResourcePlus( ) * config.waitForResourcePlus;
@@ -475,7 +475,7 @@ MapCoordinate3D AI :: findServiceBuilding ( const ServiceOrder& so, int* distanc
                                                    for ( int  j = 0; j < waffenanzahl; j++ ) {
                                                        int n = ammoNeeded[j] - bld->ammo[j];
                                                        if ( n > 0 )
-                                                          if ( bld->typ->special & cgammunitionproductionb ) {
+                                                          if ( bld->typ->hasFunction( ContainerBaseType::AmmoProduction  )) {
                                                              for ( int r = 0; r < resourceTypeNum; r++ )
                                                                 needed.resource(r) += (n+4)/5 * cwaffenproduktionskosten[j][r];
                                                           } else
@@ -545,18 +545,18 @@ MapCoordinate3D AI :: findServiceBuilding ( const ServiceOrder& so, int* distanc
 
 bool AI :: ServiceTargetEquals :: operator() (const ServiceOrder& so ) const
 {
-   pvehicle t = so.getTargetUnit();
+   Vehicle* t = so.getTargetUnit();
    return target== t;
 }
 
 
 
-void AI::removeServiceOrdersForUnit ( const pvehicle veh )
+void AI::removeServiceOrdersForUnit ( const Vehicle* veh )
 {
    serviceOrders.erase ( remove_if ( serviceOrders.begin(), serviceOrders.end(), ServiceTargetEquals( veh ) ), serviceOrders.end());
 }
 
-void AI :: runServiceUnit ( pvehicle supplyUnit )
+void AI :: runServiceUnit ( Vehicle* supplyUnit )
 {
    bool destinationReached = false;
    typedef multimap<float,ServiceOrder*> ServiceMap;
@@ -572,7 +572,7 @@ void AI :: runServiceUnit ( pvehicle supplyUnit )
           }
   /*
           veh->aiparam[getPlayerNum()]->getTask() = AiParameter::tsk_serviceRetreat;
-          pbuilding bld = findServiceBuilding( **i );
+          Building* bld = findServiceBuilding( **i );
           if ( bld )
              veh->aiparam[ getPlayerNum() ]->dest = bld->getEntry ( );
   */
@@ -598,7 +598,7 @@ void AI :: runServiceUnit ( pvehicle supplyUnit )
       VehicleService::TargetContainer::iterator i = vs.dest.find ( target );
       if ( i != vs.dest.end() ) {
          vs.fillEverything ( target, true );
-         pvehicle targetUnit = getMap()->getUnit(target);
+         Vehicle* targetUnit = getMap()->getUnit(target);
          if ( targetUnit->aiparam[getPlayerNum()]->getTask() == AiParameter::tsk_serviceRetreat )
              targetUnit->aiparam[getPlayerNum()]->resetTask();
 
@@ -630,12 +630,11 @@ AI::AiResult AI :: executeServices ( )
 
 
   for ( vector<int>::iterator vi = unitIds.begin(); vi != unitIds.end(); ++vi ) {
-      pvehicle veh = getMap()->getUnit( *vi );
+      Vehicle* veh = getMap()->getUnit( *vi );
       if ( veh ) {
         checkKeys();
-        if ( veh->aiparam[getPlayerNum()]->getJob() == AiParameter::job_supply )
+        if ( veh->aiparam[getPlayerNum()]->getJob() == AiParameter::job_supply ) 
            runServiceUnit ( veh );
-
       }
   }
 
@@ -646,8 +645,8 @@ AI::AiResult AI :: executeServices ( )
       ++nxt;
 
       if ( !i->canWait() ) {
-         pvehicle veh = i->getTargetUnit();
          displaymessage2("executing priority service order %d", ++counter);
+         Vehicle* veh = i->getTargetUnit();
          if ( i->getServiceUnit() ) {
             if ( veh->canMove() ) {
                veh->aiparam[ getPlayerNum() ]->dest = i->getServiceUnit()->getPosition();
@@ -686,7 +685,7 @@ AI::AiResult AI :: executeServices ( )
   
   counter = 0;
   for ( vector<int>::iterator vi = unitIds.begin(); vi != unitIds.end(); ++vi ) {
-     pvehicle veh = getMap()->getUnit( *vi );
+     Vehicle* veh = getMap()->getUnit( *vi );
      checkKeys();
 
      if ( veh && veh->canMove() && veh->aiparam[getPlayerNum()]->getTask() == AiParameter::tsk_serviceRetreat ) {
@@ -697,9 +696,9 @@ AI::AiResult AI :: executeServices ( )
         // the unit may have been shot down
         if ( getMap()->getUnit ( nwid )) {
            if ( veh->getPosition3D() == veh->aiparam[ getPlayerNum() ]->dest ) {
-              VehicleService vc ( mapDisplay, NULL );
-              pfield fld = getfield ( veh->xpos, veh->ypos );
+              tfield* fld = getfield ( veh->xpos, veh->ypos );
               if ( fld->building ) {
+                 VehicleService vc ( mapDisplay, NULL );
                  MapCoordinate mc = fld->building->getEntry();
                  vc.execute ( NULL, mc.x, mc.y, 0, -1, -1 );
 
@@ -726,9 +725,9 @@ AI::AiResult AI :: executeServices ( )
   /*
   for ( ServiceOrderContainer::iterator i = serviceOrders.begin(); i != serviceOrders.end(); i++ ) {
       if ( !i->timeOut() && i->requiredService == VehicleService::srv_repair ) {
-         pvehicle veh = i->getTargetUnit();
+         Vehicle* veh = i->getTargetUnit();
          veh->aiparam[getPlayerNum()]->getTask() = AiParameter::tsk_serviceRetreat;
-         pbuilding bld = findServiceBuilding( *i );
+         Building* bld = findServiceBuilding( *i );
          if ( bld )
             veh->aiparam[ getPlayerNum() ]->dest = bld->getEntry ( );
          else {
