@@ -33,6 +33,7 @@
 #include "errors.h"
 #include "sgstream.h"
 #include "graphics/blitter.h"
+#include "graphics/ColorTransform_PlayerColor.h"
 
 
 /*
@@ -76,6 +77,13 @@ BuildingType :: BuildingType ( void )
       }
 
    buildingNotRemovable = false;
+   
+   static const float matrix[] = { 1, 0, 0,
+                                   0, 1, 0,
+                                   0, 0, 1 };
+   
+   productionEfficiency = ResourceMatrix( matrix );
+   
 }
 
 
@@ -113,7 +121,7 @@ const Surface&   BuildingType :: getPicture ( const LocalCoordinate& localCoordi
    
 }
 
-void  BuildingType::paint ( Surface& s, SPoint pos, int player, int weather, int constructionStep ) const
+void  BuildingType::paint ( Surface& s, SPoint pos, const PlayerColor& player, int weather, int constructionStep ) const
 {
    for ( int x = 0; x < 4; x++ )
       for ( int y = 0; y < 6; y++ ) 
@@ -122,13 +130,23 @@ void  BuildingType::paint ( Surface& s, SPoint pos, int player, int weather, int
      
 }
 
-void  BuildingType:: paintSingleField ( Surface& s, SPoint pos, const LocalCoordinate& localCoordinate, int player, int weather, int constructionStep ) const
+void  BuildingType::paint ( Surface& s, SPoint pos  ) const
+{
+   for ( int x = 0; x < 4; x++ )
+      for ( int y = 0; y < 6; y++ ) 
+         if ( fieldExists(LocalCoordinate(x,y) ))
+            paintSingleField(s,pos,LocalCoordinate(x,y));
+     
+}
+
+
+void  BuildingType:: paintSingleField ( Surface& s, SPoint pos, const LocalCoordinate& localCoordinate, const PlayerColor& player, int weather, int constructionStep ) const
 {
    megaBlitter<ColorTransform_PlayerCol,
                ColorMerger_AlphaOverwrite,
                SourcePixelSelector_Plain,
                TargetPixelSelector_All>
-             ( getPicture(localCoordinate,weather,constructionStep), 
+            ( getPicture(localCoordinate,weather,constructionStep), 
                s, 
                SPoint( pos.x + localCoordinate.x * fielddistx + ( localCoordinate.y & 1 ) * fielddisthalfx, pos.y + localCoordinate.y * fielddisty), 
                player, 
@@ -137,6 +155,19 @@ void  BuildingType:: paintSingleField ( Surface& s, SPoint pos, const LocalCoord
    // s.Blit( getPicture(localCoordinate,weather,constructionStep),SPoint( pos.x + localCoordinate.x * fielddistx + ( localCoordinate.y & 1 ) * fielddisthalfx, pos.y + localCoordinate.y * fielddisty));
 }
 
+void  BuildingType:: paintSingleField ( Surface& s, SPoint pos, const LocalCoordinate& localCoordinate, int weather, int constructionStep ) const
+{
+   megaBlitter<ColorTransform_None,
+               ColorMerger_AlphaOverwrite,
+               SourcePixelSelector_Plain,
+               TargetPixelSelector_All>
+            ( getPicture(localCoordinate,weather,constructionStep), 
+               s, 
+               SPoint( pos.x + localCoordinate.x * fielddistx + ( localCoordinate.y & 1 ) * fielddisthalfx, pos.y + localCoordinate.y * fielddisty), 
+               nullParam, nullParam, nullParam, nullParam );
+   
+   // s.Blit( getPicture(localCoordinate,weather,constructionStep),SPoint( pos.x + localCoordinate.x * fielddistx + ( localCoordinate.y & 1 ) * fielddisthalfx, pos.y + localCoordinate.y * fielddisty));
+}
 
 
 
@@ -192,7 +223,7 @@ void BuildingType :: read ( tnstream& stream )
                    picsAvail[v][w][x][y] = stream.readInt( );
                    if ( picsAvail[v][w][x][y] ) {
                       field_Exists[x][y] = true;
-                      weatherBits.set(w);
+                      weatherBits.set(v);
                    }   
                }    
                    
@@ -205,7 +236,7 @@ void BuildingType :: read ( tnstream& stream )
                    bi_picture[v][w][x][y] = i;
                    if ( i > 0 ) {
                       field_Exists[x][y] = true;
-                      weatherBits.set(w);
+                      weatherBits.set(v);
                    }   
                }  
 
@@ -333,8 +364,9 @@ void BuildingType :: write ( tnstream& stream ) const
    for ( int v = 0; v < cwettertypennum; v++ )
       for ( int w = 0; w < maxbuildingpicnum; w++ )
          for ( int x = 0; x < 4; x++ )
-            for ( int y = 0; y < 6 ; y++ )
+            for ( int y = 0; y < 6 ; y++ ) {
                 stream.writeInt ( w_picture[v][w][x][y].valid() );
+            }
 
    for ( int v = 0; v < cwettertypennum; v++ )
       for ( int w = 0; w < maxbuildingpicnum; w++ )
@@ -602,12 +634,13 @@ void BuildingType :: runTextIO ( PropertyContainer& pc )
 
       pc.addInteger( "Armor", _armor );
 
-      if ( pc.find( "Functions" )) {
+      if ( pc.find( "Features" ) || !pc.isReading())
+         pc.addTagArray ( "Features", features, functionNum, containerFunctionTags );
+      else {
          int special = 0;
          pc.addTagInteger ( "Functions", special, cbuildingfunctionnum, buildingFunctionTags );
          convertOldFunctions( special, pc.getFileName() );
-      } else
-         pc.addTagArray ( "Features", features, functionNum, containerFunctionTags );
+      } 
       pc.addInteger ( "Techlevel", technologylevel );
 
       pc.openBracket("TerrainAccess" );
