@@ -26,6 +26,7 @@
 #include "vehicle.h"
 #include "spfst.h"
 #include "graphics/blitter.h"
+#include "graphics/ColorTransform_PlayerColor.h"
 #include "containercontrols.h"
 #include "resourcenet.h"
 
@@ -37,6 +38,14 @@ ContainerBase ::  ContainerBase ( const ContainerBaseType* bt, GameMap* map, int
    maxresearchpoints = baseType->defaultMaxResearchpoints;
    researchpoints = min ( maxresearchpoints, baseType->nominalresearchpoints );
    maxplus = baseType->maxplus;
+   
+   for ( int i = 0; i < map->getVehicleTypeNum(); ++i ) {
+      const Vehicletype* vt = map->getvehicletype_bypos(i);
+      if ( vt ) 
+         for ( int j = 0; j < bt->vehiclesInternallyProduceable.size(); ++j ) 
+            if ( vt->id >= bt->vehiclesInternallyProduceable[j].from  && vt->id <= bt->vehiclesInternallyProduceable[j].to )
+               internalUnitProduction.push_back ( vt ); 
+   }
 }
 
 SigC::Signal1<void,ContainerBase*> ContainerBase :: anyContainerDestroyed;
@@ -544,6 +553,12 @@ const ContainerBase::Production& ContainerBase::getProduction() const
    return productionCache;
 }
 
+Resources ContainerBase::getProductionCost( const Vehicletype* unit ) const
+{
+   return baseType->productionEfficiency * unit->productionCost;
+}
+
+
 void ContainerBase ::deleteProductionLine( const Vehicletype* type )
 {
    internalUnitProduction.erase( remove( internalUnitProduction.begin(), internalUnitProduction.end(), type ), internalUnitProduction.end());
@@ -653,6 +668,10 @@ Resources ContainerBase ::netResourcePlus( ) const
 
 
 
+Player& ContainerBase :: getOwningPlayer() const 
+{ 
+   return getMap()->getPlayer(this); 
+}
 
 
 
