@@ -18,6 +18,7 @@
 #ifndef containerbasetypeH
  #define containerbasetypeH
 
+ #include "objects.h"
  #include "typen.h"
  #include "research.h"
  #include "mapitemtype.h"
@@ -68,10 +69,13 @@ class ContainerBaseType: public MapItemType, public LoadableItemType, public Mem
         ImmuneToMines,
         JamsOnlyOwnField,
         MoveWithReactionFire,
-        OnlyMoveToAndFromTransports };
+        OnlyMoveToAndFromTransports,
+        AutoHarvestObjects,
+        NoProductionCustomization,
+        ManualSelfDestruct};
 
      
-     static const int functionNum = 40;
+     static const int functionNum = 43;
 
      bool hasFunction( ContainerFunctions function ) const;
      bool hasAnyFunction( std::bitset<64> functions ) const;
@@ -122,6 +126,9 @@ class ContainerBaseType: public MapItemType, public LoadableItemType, public Mem
      //! bitmapped: vehicle categories that can be produced in the container
      int vehicleCategoriesProduceable;
 
+     /** the default production capabilities of this container.
+         Please be aware that a VehicleType has additional production for building units externally */
+     vector<IntRange> vehiclesInternallyProduceable;
 
      class TransportationIO {
          public:
@@ -207,6 +214,21 @@ class ContainerBaseType: public MapItemType, public LoadableItemType, public Mem
      Resources    asc_mode_tank;
      Resources    bi_mode_tank;
      
+   public:
+
+      ResourceMatrix productionEfficiency;
+      
+      struct {
+			int range;
+         
+         int maxFieldsPerTurn;
+         
+        //! the ids of objects this unit can construct
+        vector<IntRange> objectsHarvestable;
+
+        //! the group-ids of objects this unit can construct
+        vector<IntRange> objectGroupsHarvestable;
+      } autoHarvest;
      
  };
 
