@@ -603,6 +603,25 @@ class VehicleProduction_SelectionItemFactory: public VehicleTypeSelectionItemFac
       bool fillResources;
       bool fillAmmo;
       const ContainerBase* plant;
+
+      // is initialized by the constructor's call to filterVehicleTypes
+      Container* produceables;
+      
+      Container& filterVehicleTypes( const Container& vehicles, const ContainerBase* productionplant )
+      {
+         produceables = new Container();
+         for ( Container::const_iterator i = vehicles.begin(); i != vehicles.end(); ++i ) {
+            if ( productionplant->getMap()->getgameparameter( cgp_produceOnlyResearchedStuff )) {
+               ContainerConstControls cc ( productionplant );
+               if ( !(cc.unitProductionPrerequisites( *i ) & ~(1+2+4)))  // we are filtering out the bits for lack of resource
+                  produceables->push_back( *i );
+            } else
+               produceables->push_back( *i );
+         }
+
+         return *produceables;
+      }
+
    protected:
       void vehicleTypeSelected( const Vehicletype* type, bool mouse )
       {
@@ -619,18 +638,28 @@ class VehicleProduction_SelectionItemFactory: public VehicleTypeSelectionItemFac
          sigVehicleTypeMarked( fw->getVehicletype() );
       }
 
-      const Container& getOriginalItems() { return plant->getProduction(); };
+      const Container& getOriginalItems() { 
+         delete produceables;
+         filterVehicleTypes( plant->getProduction(), plant );
+         return *produceables; 
+      };
 
    public:
       VehicleProduction_SelectionItemFactory( Resources plantResources, const ContainerBase* productionplant )
-         : VehicleTypeSelectionItemFactory( plantResources, productionplant->getProduction(), actmap->actplayer ), fillResources(true), fillAmmo(true), plant(productionplant)
+         : VehicleTypeSelectionItemFactory( plantResources, filterVehicleTypes( productionplant->getProduction(), productionplant), productionplant->getMap()->getCurrentPlayer() ), 
+           fillResources(true), 
+           fillAmmo(true), 
+           plant(productionplant)
       {
       };
       
 
       bool getAmmoFilling()
       {
-         return fillAmmo;
+          if ( plant->baseType->hasFunction(ContainerBaseType::AmmoProduction))
+             return fillAmmo;
+          else
+             return false;
       }
       
       bool setAmmoFilling( bool value )
@@ -655,9 +684,9 @@ class VehicleProduction_SelectionItemFactory: public VehicleTypeSelectionItemFac
      
       Resources getCost( const Vehicletype* type )
       {
-         Resources cost = type->productionCost;
+         Resources cost = plant->getProductionCost( type );
          if ( fillResources )
-            cost += Resources( 0, type->getStorageCapacity(actmap->_resourcemode).material, type->getStorageCapacity(actmap->_resourcemode).fuel );
+            cost += Resources( 0, type->getStorageCapacity(plant->getMap()->_resourcemode).material, type->getStorageCapacity(plant->getMap()->_resourcemode).fuel );
 
          if ( fillAmmo )
             for ( int w = 0; w < type->weapons.count; ++w )
@@ -671,13 +700,18 @@ class VehicleProduction_SelectionItemFactory: public VehicleTypeSelectionItemFac
       SigC::Signal2<void,const Vehicletype*, bool > sigVehicleTypeSelected;
       SigC::Signal1<void,const Vehicletype* > sigVehicleTypeMarked;
       
+      ~VehicleProduction_SelectionItemFactory()
+      {
+         delete produceables;  
+      }
+      
 };
 
 
 class AddProductionLine_SelectionItemFactory: public VehicleTypeSelectionItemFactory  {
       ContainerBase* plant;
    public:
-      AddProductionLine_SelectionItemFactory( ContainerBase* my_plant, const Container& types ) : VehicleTypeSelectionItemFactory( my_plant->getResource(Resources(maxint,maxint,maxint), true), types, actmap->actplayer ), plant(my_plant)
+      AddProductionLine_SelectionItemFactory( ContainerBase* my_plant, const Container& types ) : VehicleTypeSelectionItemFactory( my_plant->getResource(Resources(maxint,maxint,maxint), true), types, my_plant->getMap()->getCurrentPlayer() ), plant(my_plant)
       {
          
       };
@@ -768,7 +802,6 @@ class VehicleProduction_SelectionWindow : public ASC_PG_Dialog {
       {
          factory = new VehicleProduction_SelectionItemFactory( plant->getResource(Resources(maxint,maxint,maxint), true), plant );
 
-         factory->setAmmoFilling( CGameOptions::Instance()->unitProduction.fillAmmo );
          factory->setResourceFilling ( CGameOptions::Instance()->unitProduction.fillResources );
 
 
@@ -789,22 +822,28 @@ class VehicleProduction_SelectionWindow : public ASC_PG_Dialog {
             fillRes->SetPressed();
          fillRes->sigClick.connect( SigC::slot( *factory, &VehicleProduction_SelectionItemFactory::setResourceFilling ));
          
-         PG_CheckButton* fillAmmo = new PG_CheckButton( this, PG_Rect( 10, y + 20, r.Width() / 2 - 50, 20), "Fill with Ammo" );
-         if ( factory->getAmmoFilling() ) 
-            fillAmmo->SetPressed();
-         fillAmmo->sigClick.connect( SigC::slot( *factory, &VehicleProduction_SelectionItemFactory::setAmmoFilling ));
+         if ( plant->baseType->hasFunction(ContainerBaseType::AmmoProduction)) {
+            factory->setAmmoFilling( CGameOptions::Instance()->unitProduction.fillAmmo );
+            PG_CheckButton* fillAmmo = new PG_CheckButton( this, PG_Rect( 10, y + 20, r.Width() / 2 - 50, 20), "Fill with Ammo" );
+            if ( factory->getAmmoFilling() ) 
+               fillAmmo->SetPressed();
+            fillAmmo->sigClick.connect( SigC::slot( *factory, &VehicleProduction_SelectionItemFactory::setAmmoFilling ));
+         } else
+            factory->setAmmoFilling( false );
 
          PG_Rect rr ( r.Width() / 2 + 10, y + 2, (r.Width() - 20) - (r.Width() / 2 + 10) , 35);
          PG_Button* b  = new PG_Button( this, PG_Rect( rr.x + rr.h + 5, rr.y, rr.w - 40, rr.h ) , "Produce" );
          b->sigClick.connect( SigC::slot( *this,&VehicleProduction_SelectionWindow::produce ));
          
-         PG_Button* b2 = new PG_Button( this, PG_Rect( rr.x, rr.y, rr.h, rr.h ), "+" );
-         b2->sigClick.connect( SigC::slot( *this, &VehicleProduction_SelectionWindow::addProductionLine ));
-         new PG_ToolTipHelp( b2, "Add production line");
-
-         PG_Button* b3 = new PG_Button( this, PG_Rect( rr.x - rr.h - 5, rr.y, rr.h, rr.h ), "-" );
-         b3->sigClick.connect( SigC::slot( *this, &VehicleProduction_SelectionWindow::removeProductionLine ));
-         new PG_ToolTipHelp( b3, "Remove production line");
+         if ( !plant->baseType->hasFunction(ContainerBaseType::NoProductionCustomization)) {
+            PG_Button* b2 = new PG_Button( this, PG_Rect( rr.x, rr.y, rr.h, rr.h ), "+" );
+            b2->sigClick.connect( SigC::slot( *this, &VehicleProduction_SelectionWindow::addProductionLine ));
+            new PG_ToolTipHelp( b2, "Add production line");
+   
+            PG_Button* b3 = new PG_Button( this, PG_Rect( rr.x - rr.h - 5, rr.y, rr.h, rr.h ), "-" );
+            b3->sigClick.connect( SigC::slot( *this, &VehicleProduction_SelectionWindow::removeProductionLine ));
+            new PG_ToolTipHelp( b3, "Remove production line");
+         }
 
          
          SetTransparency(0);
@@ -2565,7 +2604,7 @@ namespace CargoGuiFunctions {
          Vehicle* veh;
       public:
          VehicleWidget( PG_Widget* parent, const PG_Point& pos, int width, Vehicle* unit )
-         : VehicleTypeBaseWidget( parent, pos, width, unit->typ, unit->getOwner() )
+         : VehicleTypeBaseWidget( parent, pos, width, unit->typ, unit->getMap()->getPlayer(unit) )
          {
             veh = unit;
          };
