@@ -33,12 +33,13 @@
 #include "../turncontrol.h"
 #include "../viewcalculation.h"
 #include "../networkinterface.h"
-#include "../network.h"
 #include "../spfst.h"
 #include "../windowing.h"
 #include "../controls.h"
 #include "../sg.h"
 #include "../gamedlg.h"
+#include "../network/simple_file_transfer.h"
+#include "../network/pbem-server.h"
 
 class GameParameterEditorWidget;
 
@@ -52,7 +53,7 @@ class StartMultiplayerGame: public ConfigurableWindow {
       enum Pages { ModeSelection = 1, FilenameSelection, PlayerSetup, EmailSetup, AllianceSetup, MapParameterEditor, MultiPlayerOptions, PasswordSearch, PBEMServerSetup }; 
       Pages page;
      
-      enum Mode { NewCampagin, ContinueCampaign, Skirmish, Hotseat, PBEM, PBP, PBEMServer };
+      enum Mode { NewCampagin, ContinueCampaign, Skirmish, Hotseat, PBEM, PBP, PBEM_Server };
       int mode;
       
       static const char* buttonLabels[];
@@ -82,6 +83,9 @@ class StartMultiplayerGame: public ConfigurableWindow {
       ASCString getDefaultPBEM_Filename();
       void setupNetwork();
       
+      PBEMServer* pbemserver;
+      
+      void loadPBEMServerDefaults();
       
       void fileNameSelected( const ASCString& filename )
       {
@@ -189,7 +193,8 @@ StartMultiplayerGame::StartMultiplayerGame(PG_MessageObject* c): ConfigurableWin
    mapParameterEditor(NULL), mapParameterEditorParent(NULL),
    allianceSetup(NULL), allianceSetupParent(NULL),
    playerSetup(NULL), playerSetupParent(NULL),
-   emailSetup(NULL), emailSetupParent(NULL)
+   emailSetup(NULL), emailSetupParent(NULL),
+   pbemserver(NULL)
 {
     setup();
     sigClose.connect( SigC::slot( *this, &StartMultiplayerGame::QuitModal ));
@@ -234,6 +239,8 @@ StartMultiplayerGame::StartMultiplayerGame(PG_MessageObject* c): ConfigurableWin
     
     showPage();
     showButtons(false,false,true);
+    
+    loadPBEMServerDefaults();
 }
 
 
@@ -241,6 +248,9 @@ StartMultiplayerGame::~StartMultiplayerGame()
 {
    if ( newMap )
       delete newMap;
+   
+   if ( pbemserver )
+      delete pbemserver;
 }      
 
 bool StartMultiplayerGame::Apply()
@@ -257,7 +267,8 @@ bool StartMultiplayerGame::Apply()
                      else
                         replay = false;
 
-
+                     if ( mode == Skirmish )
+                        replay = false; 
 
                      if ( checkPlayerStat() )
                         return true;
@@ -326,6 +337,21 @@ bool StartMultiplayerGame::Apply()
             return true;
          }      
          break;
+      case PBEMServerSetup:
+          {
+            if ( !pbemserver )
+               pbemserver = new PBEMServer();
+            
+            // @PBEMSERVER
+            // transferring the data from the dialog to the class that will be associated with the game
+            
+            
+            PG_LineEdit* le = dynamic_cast<PG_LineEdit*>( FindChild( "Server", true ));
+            if ( le &&  !le->GetText().empty() ) 
+               pbemserver->setServerAddress ( le->GetText());
+            
+         }
+         return true;
       case PasswordSearch: {
                PG_LineEdit* pw = dynamic_cast<PG_LineEdit*>( FindChild( "MapPassword", true ));
                if ( pw ) {
@@ -340,14 +366,13 @@ bool StartMultiplayerGame::Apply()
                      return false;
                   }
                   newMap = map;
-                  start();
+                  // start();
+                  return true;
                }
                            
          }
          break;
 
-
-              
       default: 
            break;
    }
@@ -405,7 +430,7 @@ bool StartMultiplayerGame::nextPage(PG_Button* button)
             break;
       case PlayerSetup: 
             if ( Apply() )
-               if ( mode == PBEM || mode == PBP || mode == PBEMServer )
+               if ( mode == PBEM || mode == PBP || mode == PBEM_Server )
                   page = EmailSetup;
                else
                   page = AllianceSetup;
@@ -413,7 +438,7 @@ bool StartMultiplayerGame::nextPage(PG_Button* button)
             break;       
       case EmailSetup: 
             if ( Apply() ) {
-               if ( mode == PBEMServer )
+               if ( mode == PBEM_Server )
                   page = PBEMServerSetup;
                else
                   page = AllianceSetup;
@@ -479,6 +504,21 @@ bool StartMultiplayerGame::nextPage(PG_Button* button)
       return false;
 }
 
+void StartMultiplayerGame::loadPBEMServerDefaults()
+{
+      if ( !pbemserver )
+         pbemserver = new PBEMServer();
+      
+      // @PBEMSERVER
+      // transferring the data from the dialog to the class that will be associated with the game
+   
+      PG_LineEdit* le = dynamic_cast<PG_LineEdit*>( FindChild( "Server", true ));
+      if ( le )
+         le->SetText( PBEMServer::getDefaultServerAddress() );
+   
+}
+
+
 void StartMultiplayerGame::showPage()
 {
    for ( int i = 0; i < 10; ++i ) {
@@ -617,7 +657,7 @@ bool StartMultiplayerGame::checkPlayerStat()
             if ( newMap->player[i].exist() )
                if ( newMap->player[i].stat == Player::computer || newMap->player[i].stat == Player::off ) {
                   newMap->player[i].stat = Player::human;
-                  msg += newMap->player[i].getName() + " has been switch to human\n";
+                  msg += newMap->player[i].getName() + " has been switched to human\n";
                   ++humanNum;
                }
             
@@ -642,7 +682,7 @@ bool StartMultiplayerGame::checkPlayerStat()
             if ( newMap->player[i].exist() )
                if ( newMap->player[i].stat == Player::computer || newMap->player[i].stat == Player::off ) {
                   newMap->player[i].stat = Player::human;
-                  msg += newMap->player[i].getName() + " has been switch to human\n";
+                  msg += newMap->player[i].getName() + " has been switched to human\n";
                   ++humanNum;
                }
    }
@@ -670,7 +710,10 @@ ASCString StartMultiplayerGame::getDefaultPBEM_Filename()
 void StartMultiplayerGame::setupNetwork()
 {
    if ( mode == PBP || mode == PBEM ) {
-      if ( newMap && !newMap->network ) {
+      if ( newMap && (!newMap->network || newMap->network->getMechanismID() != FileTransfer::mechanismID()) ) {
+         
+         delete newMap->network;
+         
          FileTransfer* ft = new FileTransfer();
          newMap->network = ft;
          
@@ -679,6 +722,14 @@ void StartMultiplayerGame::setupNetwork()
          else   
             ft->setup( getDefaultPBEM_Filename() );
       }
+   } else
+   if ( mode == PBEM_Server ) {
+      if ( newMap ) {
+         delete newMap->network;
+         newMap->network = pbemserver;
+         
+         pbemserver = NULL;
+      }
    }
 }
 
