@@ -2,88 +2,6 @@
     \brief Interface to the event handling of ASC
 */
 
-//     $Id: gameevents.h,v 1.5 2005/04/02 13:57:06 mbickel Exp $
-//
-//     $Log: gameevents.h,v $
-//     Revision 1.5  2005/04/02 13:57:06  mbickel
-//      Cleanup and new configuration scripts
-//
-//     Revision 1.4  2005/04/02 12:59:18  mbickel
-//      Fixes for MSVC compilation
-//
-//     Revision 1.3  2004/02/07 12:34:50  mbickel
-//      Fixed compilation problems
-//      Version now 1.14.0.0
-//
-//     Revision 1.2  2004/02/01 13:39:53  mbickel
-//      New event action: set view sharing
-//      Fixed lots of bugs
-//
-//     Revision 1.1  2004/01/16 19:14:55  mbickel
-//      Adding files for new event system
-//
-//     Revision 1.12  2003/07/06 13:16:22  mbickel
-//      Updated maps
-//
-//     Revision 1.11  2003/06/26 21:00:18  mbickel
-//      Fixed: land mines could not be carried on bridges
-//
-//     Revision 1.10  2003/05/01 18:02:22  mbickel
-//      Fixed: no movement decrease for cargo when transport moved
-//      Fixed: reactionfire not working when descending into range
-//      Fixed: objects not sorted
-//      New map event: add object
-//
-//     Revision 1.9  2003/01/28 17:48:42  mbickel
-//      Added sounds
-//      Rewrote soundsystem
-//      Fixed: tank got stuck when moving from one transport ship to another
-//
-//     Revision 1.8  2001/02/26 12:35:23  mbickel
-//      Some major restructuing:
-//       new message containers
-//       events don't store pointers to units any more
-//       tfield class overhauled
-//
-//     Revision 1.7  2001/02/11 11:39:40  mbickel
-//      Some cleanup and documentation
-//
-//     Revision 1.6  2001/01/28 14:04:14  mbickel
-//      Some restructuring, documentation and cleanup
-//      The resource network functions are now it their own files, the dashboard
-//       as well
-//      Updated the TODO list
-//
-//     Revision 1.5  2001/01/19 13:33:51  mbickel
-//      The AI now uses hemming
-//      Several bugfixes in Vehicle Actions
-//      Moved all view calculation to viewcalculation.cpp
-//      Mapeditor: improved keyboard support for item selection
-//
-//     Revision 1.4  2000/10/11 14:26:44  mbickel
-//      Modernized the internal structure of ASC:
-//       - vehicles and buildings now derived from a common base class
-//       - new resource class
-//       - reorganized exceptions (errors.h)
-//      Split some files:
-//        typen -> typen, vehicletype, buildingtype, basecontainer
-//        controls -> controls, viewcalculation
-//        spfst -> spfst, mapalgorithm
-//      bzlib is now statically linked and sources integrated
-//
-//     Revision 1.3  2000/07/05 10:49:36  mbickel
-//      Fixed AI bugs
-//      setbuildingdamage event now updates the screen
-//
-//     Revision 1.2  1999/11/16 03:42:10  tmwilson
-//     	Added CVS keywords to most of the files.
-//     	Started porting the code to Linux (ifdef'ing the DOS specific stuff)
-//     	Wrote replacement routines for kbhit/getch for Linux
-//     	Cleaned up parts of the code that gcc barfed on (char vs unsigned char)
-//     	Added autoconf/automake capabilities
-//     	Added files used by 'automake --gnu'
-//
-//
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
     Copyright (C) 1994-1999  Martin Bickel  and  Marc Schellenberger
@@ -109,7 +27,6 @@
 #define gameeventsH
 
 #include "typen.h"
-#include "mapdisplay.h"
 #include "gameeventsystem.h"
 #include "mappolygons.h"
 
@@ -160,13 +77,14 @@ enum EventAction_ID { EventAction_Nothing,
                      EventAction_ChangeDiplomaticStatus,
                      EventAction_AddResources,
                      EventAction_Reinforcements,
-                     EventAction_SetViewSharing };
+                     EventAction_SetViewSharing,
+                     EventAction_ChangePlayerState };
 
 
 class EventTriggered;
 
-class FieldAddressing: protected PolygonPainerSquareCoordinate  {
-      pmap& gameMap;
+class FieldAddressing: protected PolygonPainterSquareCoordinate  {
+      GameMap*& gameMap;
    public:
       typedef vector<MapCoordinate> Fields;
       typedef vector< Poly_gon > Polygons;
@@ -177,7 +95,7 @@ class FieldAddressing: protected PolygonPainerSquareCoordinate  {
       virtual ~FieldAddressing() {};
 
    protected:
-      FieldAddressing( pmap& gamemap ) : gameMap(gamemap), addressingMode( none )  {};
+      FieldAddressing( GameMap*& gamemap ) : gameMap(gamemap), addressingMode( none ) {};
       enum AddressingMode { none, singleField, poly, global };
 
       AddressingMode addressingMode;
@@ -191,7 +109,7 @@ class FieldAddressing: protected PolygonPainerSquareCoordinate  {
       void setpointabs ( int x,  int y  );
 
       void setup();
-      friend Event* readOldEvent( pnstream stream, pmap gamemap, map<int,int>& eventTranslation, map<EventTriggered*,int>& eventTriggerEvents );
+      friend Event* readOldEvent( pnstream stream, GameMap* gamemap, map<int,int>& eventTranslation, map<EventTriggered*,int>& eventTriggerEvents );
 };
 
 
@@ -209,7 +127,8 @@ class TriggerNothingTrue: public TriggerNothing {
       State getState( int player ) { return finally_fulfilled; };
    public:
       TriggerNothingTrue() : TriggerNothing( Trigger_NothingTrue ) {};
-      ASCString getName() const { return "Nothing (true)"; };
+      ASCString getTypeName() const { return "Nothing (always true)"; };
+      ASCString getDetailledName() const { return getTypeName(); };
 };
 
 class TriggerNothingFalse: public TriggerNothing {
@@ -217,7 +136,8 @@ class TriggerNothingFalse: public TriggerNothing {
       State getState( int player ) { return finally_failed; };
    public:
       TriggerNothingFalse() : TriggerNothing( Trigger_NothingFalse ) {};
-      ASCString getName() const { return "Nothing (false)"; };
+      ASCString getTypeName() const { return "Nothing (always false)"; };
+      ASCString getDetailledName() const { return getTypeName(); };
 };
 
 
@@ -228,12 +148,13 @@ class TurnPassed : public EventTrigger {
     protected:
       virtual State getState( int player );
     public:
-      TurnPassed() : EventTrigger ( Trigger_TurnPassed ), turn( 0 ), move( 0 ) {};
+      TurnPassed() : EventTrigger ( Trigger_TurnPassed ), turn( -1 ), move( -1 ) {};
       TurnPassed( int turn_, int move_ ) : EventTrigger ( Trigger_TurnPassed ), turn( turn_ ), move( move_ ) {};
 
       virtual void readData ( tnstream& stream ) ;
       virtual void writeData ( tnstream& stream ) ;
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void setup();
       void arm();
 };
@@ -259,7 +180,8 @@ class UnitLost : public UnitTrigger {
     public:
       UnitLost() : UnitTrigger ( Trigger_UnitLost ) {};
       UnitLost( int unitID_) : UnitTrigger ( Trigger_UnitLost ) { unitID = unitID_;};
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void arm();
 };
 
@@ -269,7 +191,8 @@ class UnitConquered : public UnitTrigger {
     public:
       UnitConquered() : UnitTrigger ( Trigger_UnitConquered ) {};
       UnitConquered( int unitID_) : UnitTrigger ( Trigger_UnitConquered ) { unitID = unitID_;};
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void arm();
 };
 
@@ -279,7 +202,8 @@ class UnitDestroyed : public UnitTrigger {
     public:
       UnitDestroyed() : UnitTrigger ( Trigger_UnitDestroyed ) {};
       UnitDestroyed( int unitID_) : UnitTrigger ( Trigger_UnitDestroyed ) { unitID = unitID_;};
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void arm();
 };
 
@@ -293,7 +217,8 @@ class AllBuildingsLost : public EventTrigger {
 
       virtual void readData ( tnstream& stream ) { stream.readInt(); };
       virtual void writeData ( tnstream& stream ) { stream.writeInt(1); };
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void setup() {};
 };
 
@@ -305,7 +230,8 @@ class AllUnitsLost : public EventTrigger {
 
       virtual void readData ( tnstream& stream ) { stream.readInt(); };
       virtual void writeData ( tnstream& stream ) { stream.writeInt(1); };
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void setup() {};
 };
 
@@ -335,7 +261,8 @@ class BuildingConquered : public BuildingPositionTrigger, public SigC::Object {
     public:
       BuildingConquered() : BuildingPositionTrigger( Trigger_BuildingConquered ) {};
       BuildingConquered( const MapCoordinate& position) : BuildingPositionTrigger( Trigger_BuildingConquered ) { pos = position;};
-      ASCString getName() const { return BuildingPositionTrigger::getName() + " conquered"; };
+      ASCString getTypeName() const { return "Building conquered"; };
+      ASCString getDetailledName() const { return BuildingPositionTrigger::getName() + " conquered"; };
       void arm();
       void triggered();
 };
@@ -346,7 +273,8 @@ class BuildingLost: public BuildingConquered  {
    public:
       BuildingLost ( ) : BuildingConquered( Trigger_BuildingLost ) {};
       BuildingLost( const MapCoordinate& position) : BuildingConquered( position ) {};
-      ASCString getName() const { return BuildingPositionTrigger::getName() + " Lost"; };
+      ASCString getTypeName() const { return "Building lost"; };
+      ASCString getDetailledName() const { return BuildingPositionTrigger::getName() + " conquered"; };
       void arm();
 };
 
@@ -356,7 +284,8 @@ class BuildingDestroyed : public BuildingPositionTrigger {
     public:
       BuildingDestroyed() : BuildingPositionTrigger ( Trigger_BuildingDestroyed ) {};
       BuildingDestroyed( const MapCoordinate& position) : BuildingPositionTrigger( Trigger_BuildingDestroyed ) { pos = position;};
-      ASCString getName() const { return BuildingPositionTrigger::getName() + " destroyed"; };
+      ASCString getTypeName() const { return "Building destroyed"; };
+      ASCString getDetailledName() const { return BuildingPositionTrigger::getName() + " destroyed"; };
 };
 
 class BuildingSeen : public BuildingPositionTrigger, public SigC::Object {
@@ -365,7 +294,8 @@ class BuildingSeen : public BuildingPositionTrigger, public SigC::Object {
     public:
       BuildingSeen() : BuildingPositionTrigger ( Trigger_BuildingSeen ) {};
       BuildingSeen( const MapCoordinate& position) : BuildingPositionTrigger( Trigger_BuildingSeen ) { pos = position;};
-      ASCString getName() const { return BuildingPositionTrigger::getName() + " seen"; };
+      ASCString getTypeName() const { return "Building seen"; };
+      ASCString getDetailledName() const { return BuildingPositionTrigger::getName() + " seen"; };
       void arm();
       void triggered();
 };
@@ -381,14 +311,17 @@ class EventTriggered : public EventTrigger, public SigC::Object {
 
       virtual void readData ( tnstream& stream );
       virtual void writeData ( tnstream& stream );
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void setup();
       void arm();
       void triggered();
 };
 
 class AllEnemyUnitsDestroyed : public EventTrigger, public SigC::Object {
-    protected:
+   private:
+      void triggered();
+   protected:
       virtual State getState( int player );
     public:
       AllEnemyUnitsDestroyed() : EventTrigger ( Trigger_AllEnemyUnitsDestroyed ) {};
@@ -396,24 +329,26 @@ class AllEnemyUnitsDestroyed : public EventTrigger, public SigC::Object {
       virtual void readData ( tnstream& stream ) { stream.readInt(); };
       virtual void writeData ( tnstream& stream ) { stream.writeInt(1); };
 
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void setup() {};
       void arm();
-      void triggered();
 };
 
 class AllEnemyBuildingsDestroyed : public EventTrigger, public SigC::Object {
-    protected:
+   private:
+      void triggered();
+   protected:
       virtual State getState( int player );
     public:
       AllEnemyBuildingsDestroyed() : EventTrigger ( Trigger_AllEnemyBuildingsDestroyed ) {};
 
       virtual void readData ( tnstream& stream ) { stream.readInt(); };
       virtual void writeData ( tnstream& stream ) { stream.writeInt(1); };
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void setup() {};
       void arm();
-      void triggered();
 };
 
 class SpecificUnitEntersPolygon : public EventTrigger, public FieldAddressing, public SigC::Object {
@@ -430,10 +365,11 @@ class SpecificUnitEntersPolygon : public EventTrigger, public FieldAddressing, p
       void setup();
       void arm();
       void triggered();
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
 
     protected:
       void fieldOperator( const MapCoordinate& mc );
-      ASCString getName() const;
 };
 
 class AnyUnitEntersPolygon : public EventTrigger, public FieldAddressing, public SigC::Object {
@@ -450,10 +386,11 @@ class AnyUnitEntersPolygon : public EventTrigger, public FieldAddressing, public
       void setup();
       void arm();
       void triggered();
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
 
     protected:
       void fieldOperator( const MapCoordinate& mc );
-      ASCString getName() const;
 };
 
 
@@ -468,7 +405,8 @@ class ResourceTribute : public EventTrigger, public SigC::Object {
 
       virtual void readData ( tnstream& stream );
       virtual void writeData ( tnstream& stream );
-      ASCString getName() const;
+      ASCString getTypeName() const;
+      ASCString getDetailledName() const;
       void setup();
       void arm();
       void triggered();
@@ -487,6 +425,9 @@ class Action_Nothing: public EventAction {
 
       void execute( MapDisplayInterface* md ) {};
       void setup() {};
+
+      ASCString getName() const { return "-nothing-"; };
+
 };
 
 
@@ -507,11 +448,16 @@ class WindChange: public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Wind change"; };
+
 };
 
 class ChangeGameParameter: public EventAction {
       int parameterNum;
       int parameterValue;
+      int selectgameparameter( int para );
+
     public:
      ChangeGameParameter(): EventAction( EventAction_ChangeGameParameter ),
                             parameterNum(-1),
@@ -526,6 +472,9 @@ class ChangeGameParameter: public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Change game parameter"; };
+
 };
 
 class DisplayMessage: public EventAction {
@@ -541,6 +490,8 @@ class DisplayMessage: public EventAction {
       void execute( MapDisplayInterface* md );
 
       void setup();
+
+      ASCString getName() const { return "Display Message (from text file)"; };
 };
 
 
@@ -562,6 +513,9 @@ class WeatherChange : public MapModificationEvent {
       void writeData ( tnstream& stream );
 
       void setup();
+
+      ASCString getName() const { return "Weather change"; };
+
 };
 
 class MapChange : public MapModificationEvent {
@@ -574,6 +528,8 @@ class MapChange : public MapModificationEvent {
       void readData ( tnstream& stream );
       void writeData ( tnstream& stream );
       void setup();
+
+      ASCString getName() const { return "Map Change"; };
 };
 
 class AddObject : public MapModificationEvent {
@@ -588,6 +544,8 @@ class AddObject : public MapModificationEvent {
       void readData ( tnstream& stream );
       void writeData ( tnstream& stream );
       void setup();
+
+      ASCString getName() const { return "Add object"; };
 };
 
 
@@ -600,6 +558,9 @@ class MapChangeCompleted : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup() {};
+
+      ASCString getName() const { return "map change completed"; };
+
 };
 
 
@@ -617,6 +578,8 @@ class ChangeBuildingDamage: public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Change building damage"; };
 };
 
 class NextMap : public EventAction {
@@ -630,6 +593,9 @@ class NextMap : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Next Map in Campaign"; };
+
 };
 
 class LoseMap : public EventAction {
@@ -641,6 +607,9 @@ class LoseMap : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup() {};
+
+      ASCString getName() const { return "Lose Map"; };
+
 };
 
 class DisplayEllipse : public EventAction {
@@ -660,6 +629,9 @@ class DisplayEllipse : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Display Ellipse (legacy event)"; };
+
 };
 
 class RemoveEllipse : public EventAction {
@@ -671,6 +643,9 @@ class RemoveEllipse : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup() {};
+
+      ASCString getName() const { return "Remove ellipse (legacy event)"; };
+
 };
 
 class RemoveAllObjects : public MapModificationEvent {
@@ -681,6 +656,9 @@ class RemoveAllObjects : public MapModificationEvent {
       void readData ( tnstream& stream );
       void writeData ( tnstream& stream );
       void setup();
+
+      ASCString getName() const { return "Remove all objects"; };
+
 };
 
 class ChangeBuildingOwner : public EventAction {
@@ -694,18 +672,24 @@ class ChangeBuildingOwner : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Change Building Owner"; };
 };
 
 class DisplayImmediateMessage: public EventAction {
       ASCString message;
+      int recipients;
     public:
-      DisplayImmediateMessage(): EventAction( EventAction_DisplayImmediateMessage ) {};
+      DisplayImmediateMessage(): EventAction( EventAction_DisplayImmediateMessage ), recipients(0) {};
       void readData ( tnstream& stream );
       void writeData ( tnstream& stream );
 
       void execute( MapDisplayInterface* md );
 
       void setup();
+
+      ASCString getName() const { return "Display Message (immediate text)"; };
+
 };
 
 class AddProductionCapability : public EventAction {
@@ -719,6 +703,9 @@ class AddProductionCapability : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Add Production Capability"; };
+
 };
 
 
@@ -734,6 +721,9 @@ class ChangeDiplomaticStatus : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Change Diplomatic Status"; };
+
 };
 
 class SetViewSharing : public EventAction {
@@ -748,6 +738,9 @@ class SetViewSharing : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Set view sharing"; };
+
 };
 
 
@@ -762,11 +755,14 @@ class AddResources : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Add Resources to Building"; };
 };
 
 class Reinforcements : public EventAction {
       tmemorystreambuf buf;
       int objectNum;
+      friend class ReinforcementSelector;
       enum Type { ReinfVehicle, ReinfBuilding };
    public:
       Reinforcements(): EventAction( EventAction_Reinforcements ), objectNum(0) {};
@@ -776,6 +772,9 @@ class Reinforcements : public EventAction {
 
       void execute( MapDisplayInterface* md );
       void setup();
+
+      ASCString getName() const { return "Reinforcements"; };
+
 };
 
 
