@@ -286,7 +286,7 @@ void GameMap :: guiHooked()
    dialogsHooked = true;
 }
 
-const int tmapversion = 20;
+const int tmapversion = 21;
 
 void GameMap :: read ( tnstream& stream )
 {
@@ -969,7 +969,7 @@ bool GameMap :: isResourceGlobal ( int resource )
    }
 }
 
-int GameMap :: getgameparameter ( GameParameter num )
+int GameMap :: getgameparameter ( GameParameter num ) const
 {
   if ( game_parameter && num < gameparameter_num ) {
      return game_parameter[num];
@@ -1061,7 +1061,7 @@ Vehicle* GameMap :: getUnit ( Vehicle* eht, int nwid )
          return eht;
       else
          for ( ContainerBase::Cargo::const_iterator i = eht->getCargo().begin(); i != eht->getCargo().end(); ++i )
-            if ( *i ) 
+            if ( *i )  {
                if ( (*i)->networkid == nwid )
                   return *i;
                else {
@@ -1069,6 +1069,7 @@ Vehicle* GameMap :: getUnit ( Vehicle* eht, int nwid )
                   if ( ld )
                      return ld;
                }
+            }
       return NULL;
    }
 }
@@ -1220,7 +1221,7 @@ void GameMap::endRound()
        for ( int x = 0; x < xsize; ++x )
            getField(x,y)->endRound( time.turn() );
 
-    for (int i = 0; i <= 7; i++)
+    for (int i = 0; i <= 7; i++) {
        if (player[i].exist() && player[i].stat != Player::off ) {
 
           for ( Player::VehicleList::iterator j = player[i].vehicleList.begin(); j != player[i].vehicleList.end(); j++ )
@@ -1257,6 +1258,7 @@ void GameMap::endRound()
           } while ( didSomething );
           doresearch( this, i );
        }
+    }
 
     if ( getgameparameter( cgp_objectGrowthMultiplier) > 0 )
        objectGrowth();
@@ -1671,7 +1673,7 @@ void GameMap::processJournal()
      int fnd;
      do {
         fnd = 0;
-        if ( !add.empty() )
+        if ( !add.empty() ) {
            if ( add.find ( '\n', add.length()-1 ) != add.npos ) {
               add.erase ( add.length()-1 );
               fnd++;
@@ -1681,6 +1683,7 @@ void GameMap::processJournal()
                   add.erase ( add.length()-5 );
                   fnd++;
                 }
+        }
 
      } while ( fnd ); /* enddo */
 
@@ -2071,6 +2074,7 @@ GameParameterSettings gameParameterSettings[gameparameternum ] = {
       {  "DebugGameEvents",                    0,                    0,   2,                  true,   false,   "debug game events"},  //       cgp_debugEvents
       {  "ObjectGrowthRate",                   0,                    0,   maxint,             true,   false,   "Object growth rate (percentage)" },  //       cgp_objectGrowthMultiplier
       {  "ObjectsGrowOnOtherObjects",          1,                    0,   1,                  false,  false,   "Objects can grow on fields with other objects"  },  //       cgp_objectGrowOnOtherObjects
-      {  "ResearchOutputMultiplier",           1,                    1,   maxint,             false,   false,   "Multiplies the research output of all labs"  }  //       cgp_researchOutputMultiplier
+      {  "ResearchOutputMultiplier",           1,                    1,   maxint,             false,  false,   "Multiplies the research output of all labs"  },  //       cgp_researchOutputMultiplier
+      {  "ProduceOnlyResearchedStuff",         0,                    0,   1,                  true,   false,   "Produce only researched stuff" }
 };
 
