@@ -59,7 +59,7 @@ class WeatherSystem;
 #endif
 
 //! The number of game paramters that can be specified for each map.
-const int gameparameternum = 33;
+const int gameparameternum = 34;
 
 enum GameParameter { cgp_fahrspur,
        cgp_eis,
@@ -93,7 +93,8 @@ enum GameParameter { cgp_fahrspur,
        cgp_debugEvents,
        cgp_objectGrowthMultiplier,
        cgp_objectGrowOnOtherObjects,
-       cgp_researchOutputMultiplier};
+       cgp_researchOutputMultiplier,
+       cgp_produceOnlyResearchedStuff };
 
 
 struct GameParameterSettings {
@@ -309,9 +310,9 @@ public:
       public:
           ReplayInfo ( void );
 
-          pmemorystreambuf guidata[8];
-          pmemorystreambuf map[8];
-          pmemorystream    actmemstream;
+          tmemorystreambuf* guidata[8];
+          tmemorystreambuf* map[8];
+          tmemorystream*    actmemstream;
 
           //! if stopRecordingActions > 0 then no actions will be recorded. \see LockReplayRecording
           int stopRecordingActions;
@@ -381,7 +382,7 @@ public:
       Vehicle* getUnit ( int x, int y, int nwid );
       Vehicle* getUnit ( int nwid );
       ContainerBase* getContainer ( int nwid );
-      int  getgameparameter ( GameParameter num );
+      int  getgameparameter ( GameParameter num ) const;
       void setgameparameter ( GameParameter num, int value );
       void cleartemps( int b = -1, int value = 0 );
       bool isResourceGlobal ( int resource );
