@@ -158,9 +158,21 @@ void CGameOptions::runTextIO ( PropertyContainer& pc )
    pc.addBool("fillAmmo", unitProduction.fillAmmo, true );
    pc.closeBracket();
    
+   pc.openBracket("replayVideo");
+   pc.addInteger("FrameRate", video.framerate, video.framerate );
+   pc.addInteger("Quality", video.quality, video.quality);
+   pc.closeBracket();
+   
    if ( !pc.isReading() || pc.find("VisibleMapLayer" ))
       pc.addStringArray("VisibleMapLayer", visibleMapLayer );
 
+
+   pc.openBracket("PBEMServer");
+   pc.addString("hostname", pbemServer.hostname, pbemServer.hostname );
+   pc.addString("username", pbemServer.username, pbemServer.username );
+   pc.addInteger("port", pbemServer.port, pbemServer.port );
+   pc.closeBracket();
+
    /*
    add(new IntProperty("BI3.interpolate.terrain"		,	&_pOptions->bi3.interpolate.terrain));
    add(new IntProperty("BI3.interpolate.units"			,	&_pOptions->bi3.interpolate.units));
@@ -289,8 +301,15 @@ void CGameOptions::setDefaults ( void )
    unitProduction.fillAmmo = true;
    unitProduction.fillResources = true;
 
+   video.quality = 100;
+   video.framerate = 15;
+   
    panelColumns = 2;
 
+   pbemServer.username="";
+   pbemServer.port = 8080;
+   pbemServer.hostname="terdon.asc-hq.org";
+
    setChanged();
 }
 
