@@ -216,6 +216,12 @@ class CGameOptions
       
       ASCString BI3directory;
 
+      struct {
+         ASCString hostname;
+         int port;
+         ASCString username;
+      } pbemServer;
+
       ASCString graphicsDriver;
 
       ASCString startupMap;
@@ -224,6 +230,10 @@ class CGameOptions
       Password getDefaultPassword ( );
       Password getDefaultSupervisorPassword ( );
 
+      struct {
+         int framerate;
+         int quality;
+      } video;
 
       static const int maxSearchPathNum;
       int searchPathNum;
