@@ -500,6 +500,8 @@ void megaBlitter  ( const Surface& src,
 
 //////////////////// Color transformations ////////////////////////////////////
 
+class Player;
+
 
 template<int pixelsize>
 class ColorTransform_None
@@ -522,187 +524,6 @@ class ColorTransform_None
       ;
 };
 
-template<int pixelsize>
-class ColorTransform_PlayerCol
-{
-      typedef typename PixelSize2Type<pixelsize>::PixelType PixelType;
-   protected:
-      ColorTransform_PlayerCol()
-      {}
-      ;
-
-      PixelType transform( PixelType col)
-      {
-         return col;
-      };
-
-      void init( const Surface& src )
-      {}
-      ;
-
-   public:
-      ColorTransform_PlayerCol( int player )
-      {}
-      ;
-      ColorTransform_PlayerCol ( NullParamType npt )
-      {}
-      ;
-
-      void setPlayer( int player )
-      {}
-      ;
-};
-
-template<>
-class ColorTransform_PlayerCol<1>
-{
-      int shift;
-      typedef PixelSize2Type<1>::PixelType PixelType;
-
-   protected:
-      ColorTransform_PlayerCol() : shift(0)
-      {}
-      ;
-
-      PixelType transform( PixelType col)
-      {
-         if ( col >= 16 && col < 24 )
-            return col + shift;
-         else
-            return col;
-      };
-
-      void init( const Surface& src )
-   {}
-      ;
-
-   public:
-      ColorTransform_PlayerCol( int player )
-      {
-         setPlayer( player );
-      };
-
-      ColorTransform_PlayerCol ( NullParamType npt ) : shift(0)
-      {}
-      ;
-
-      void setPlayer( int player )
-      {
-         shift = player*8;
-      };
-};
-/*
-   template<int pixelSize>
-  class ColorTransform_PlayerCol {
-        typedef typename PixelSize2Type<pixelsize>::PixelType PixelType;
-    protected:
-        ColorTransform_PlayerCol() : shift(0) {};
- 
-        PixelType transform( PixelType col) { return col; };
- 
-     public:
-        ColorTransform_PlayerCol( int player ) {};
-        ColorTransform_PlayerCol ( NullParamType npt ) : shift(0) {};
- 
-        void setPlayer( int player ){};
- };
- 
- 
-  template<>
-  class ColorTransform_PlayerCol<4> {
-        int color;
-        typedef PixelSize2Type<4>::PixelType PixelType;
- 
-    protected:
-        ColorTransform_PlayerCol() : shift(0) {};
- 
-        PixelType transform( PixelType col)
-        {
-           if ( col >= 16 && col < 24 )
-              return col + shift;
-           else
-              return col;
-        };
- 
-     public:
-        ColorTransform_PlayerCol( int player )
-        {
-           setPlayer( player );
-        };
- 
-        ColorTransform_PlayerCol ( NullParamType npt ) : shift(0) {};
- 
-        void setPlayer( int player )
-        {
-           shift = player*8;
-        };
- };
-*/
-
-
-template<int pixelsize>
-class ColorTransform_PlayerTrueCol
-{
-      typedef typename PixelSize2Type<pixelsize>::PixelType PixelType;
-      bool lateConversion;
-      DI_Color sourceColor;
-
-      PixelType refColor;
-      int refr, refg, refb;  // this is NOT RED, GREEN, BLUE, but device dependant. Should be renamed
-   protected:
-      ColorTransform_PlayerTrueCol() : refColor(0),refr(0),refg(0),refb(0)
-      {}
-      ;
-
-      PixelType transform( PixelType col)
-      {
-         int r = (col >> 16) & 0xff;
-         int g = (col >> 8) & 0xff;
-         int b = (col ) & 0xff;
-         if ( g==0 && b==0) {
-            return ((refr * r / 256) << 16) + ((refg * r / 256) << 8) + (refb * r / 256) + (col & 0xff000000);
-         } else
-            if ( r==255 && g==b ) {
-               return ((refr + ( 255-refr) * g / 255) << 16) + ((refg + ( 255-refg) * g / 255) << 8) + (refb + ( 255-refb) * g / 255) + (col & 0xff000000);
-            } else
-               return col;
-      };
-
-      void init( const Surface& src )
-      {
-         if ( lateConversion ) {
-            setColor( src.GetPixelFormat().MapRGB( sourceColor ));
-            lateConversion = false;
-         }
-      }
-
-   public:
-      ColorTransform_PlayerTrueCol( PixelType color ) : lateConversion( false )
-      {
-         setColor(color);
-      };
-      ColorTransform_PlayerTrueCol( DI_Color color ) : lateConversion( false )
-      {
-         setColor(color);
-      };
-      ColorTransform_PlayerTrueCol ( NullParamType npt ) : lateConversion( false ) , refColor(0),refr(0),refg(0),refb(0)
-      {}
-      ;
-
-      void setColor( PixelType color )
-      {
-         refColor = color;
-         refr = (color >> 16) & 0xff;
-         refg = (color >> 8) & 0xff;
-         refb = (color ) & 0xff;
-      };
-
-      void setColor( DI_Color color )
-      {
-         lateConversion = true;
-         sourceColor = color;
-      };
-};
 
 
 
