@@ -49,6 +49,7 @@
 #include "dialogs/buildingtypeselector.h"
 #include "dialogs/internalAmmoTransferDialog.h"
 #include "actions/jumpdrive.h"
+#include "actions/selfdestruct.h"
 
 
 namespace GuiFunctions
@@ -1467,6 +1468,7 @@ class PutAntiTankMine : public PutGroundMine
       void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
       {
          putMine(pos, cmantitankmine, 1 );
+         updateFieldInfo();
          displaymap();
       }
 
@@ -1487,6 +1489,7 @@ class PutAntiPersonalMine : public PutGroundMine
       void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
       {
          putMine(pos, cmantipersonnelmine, 1);
+         updateFieldInfo();
          displaymap();
       }
 
@@ -1525,6 +1528,7 @@ class PutAntiShipMine : public GuiFunction
       void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
       {
          putMine( pos, cmfloatmine, 1);
+         updateFieldInfo();
          displaymap();
       }
 
@@ -1558,6 +1562,7 @@ class PutAntiSubMine : public GuiFunction
       void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
       {
          putMine( pos, cmmooredmine,1 );
+         updateFieldInfo();
          displaymap();
       }
 
@@ -2604,7 +2609,7 @@ class BuildingConstructionSelection : public BuildingTypeSelectionItemFactory {
    protected:
       void BuildingTypeSelected( const BuildingType* type ) { selectedType = type;  };
    public:
-      BuildingConstructionSelection ( Resources plantResources, const Container& types, int player ) : BuildingTypeSelectionItemFactory(plantResources, types, player ), selectedType(NULL) {};
+      BuildingConstructionSelection ( Resources plantResources, const Container& types, const Player& player ) : BuildingTypeSelectionItemFactory(plantResources, types, player ), selectedType(NULL) {};
       const BuildingType* getSelectedType() { return selectedType; };
 };
 
@@ -2629,7 +2634,7 @@ void ConstructBuilding::execute(  const MapCoordinate& pos, ContainerBase* subje
             return;
          }
 
-         BuildingConstructionSelection* bcs = new BuildingConstructionSelection ( fld->vehicle->getResource( Resources(maxint, maxint, maxint), true ), buildings, fld->vehicle->getOwner() );
+         BuildingConstructionSelection* bcs = new BuildingConstructionSelection ( fld->vehicle->getResource( Resources(maxint, maxint, maxint), true ), buildings, fld->vehicle->getOwningPlayer() );
          ItemSelectorWindow isw ( NULL, PG_Rect( -1, -1, 550, 650), "Select Building", bcs);
          isw.Show();
          isw.RunModal();
@@ -2656,225 +2661,6 @@ void ConstructBuilding::execute(  const MapCoordinate& pos, ContainerBase* subje
 
 
 
-class ReplayPlay : public GuiFunction
-{
-   public:
-      bool available( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         if ( runreplay.status == 1 )
-            return true;
-
-         return false;
-      };
-
-      void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-        runreplay.status = 2;
-        updateFieldInfo();
-      }
-
-      Surface& getImage( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return IconRepository::getIcon("replay-play.png");
-      };
-
-      ASCString getName( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return "start re~p~lay";
-      };
-
-      bool checkForKey( const SDL_KeyboardEvent* key, int modifier, int num )
-      {
-         return ( key->keysym.unicode == 'p' );
-      };
-      
-};
-
-
-class ReplayPause : public GuiFunction
-{
-   public:
-      bool available( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         if ( runreplay.status == 2 )
-            return true;
-
-         return false;
-      };
-
-      void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-        runreplay.status = 1;
-        updateFieldInfo();
-      }
-
-      Surface& getImage( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return IconRepository::getIcon("replay-pause.png");
-      };
-
-      ASCString getName( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return "~p~ause replay";
-      };
-      
-      bool checkForKey( const SDL_KeyboardEvent* key, int modifier, int num )
-      {
-         return ( key->keysym.unicode == 'p' );
-      };
-      
-};
-
-
-
-class ReplayFaster : public GuiFunction
-{
-   public:
-      bool available( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         if ( runreplay.status == 2 )
-            if ( CGameOptions::Instance()->replayspeed > 0 )
-              return true;
-
-         return false;
-      };
-
-      void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         if ( CGameOptions::Instance()->replayspeed > 20 )
-            CGameOptions::Instance()->replayspeed -= 20;
-         else
-            CGameOptions::Instance()->replayspeed = 0;
-
-         CGameOptions::Instance()->setChanged ( 1 );
-         displaymessage2 ( "delay set to %d / 100 sec", CGameOptions::Instance()->replayspeed );
-         updateFieldInfo();
-      }
-
-      Surface& getImage( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return IconRepository::getIcon("replay-faster.png");
-      };
-
-      ASCString getName( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return "increase replay speed (~+~)";
-      };
-
-      bool checkForKey( const SDL_KeyboardEvent* key, int modifier, int num )
-      {
-         return ( key->keysym.unicode == '+' || key->keysym.sym == SDLK_KP_PLUS);
-      };
-      
-};
-
-
-class ReplaySlower : public GuiFunction
-{
-   public:
-      bool available( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         if ( runreplay.status == 2 )
-            return true;
-
-         return false;
-      };
-
-      void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         CGameOptions::Instance()->replayspeed += 20;
-         CGameOptions::Instance()->setChanged ( 1 );
-         displaymessage2 ( "delay set to %d / 100 sec", CGameOptions::Instance()->replayspeed );
-         updateFieldInfo();
-      }
-
-      Surface& getImage( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return IconRepository::getIcon("replay-slow.png");
-      };
-
-      ASCString getName( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return "decrease replay speed (~-~)";
-      };
-
-      bool checkForKey( const SDL_KeyboardEvent* key, int modifier, int num )
-      {
-         return ( key->keysym.unicode == '-' || key->keysym.sym == SDLK_KP_MINUS);
-      };
-      
-};
-
-
-class ReplayRewind : public GuiFunction
-{
-   public:
-      bool available( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         if ( runreplay.status == 1  ||  runreplay.status == 10 )
-              return true;
-
-         return false;
-      };
-
-      void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         runreplay.status = 101;
-         updateFieldInfo();
-      }
-
-      Surface& getImage( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return IconRepository::getIcon("replay-back.png");
-      };
-
-      ASCString getName( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return "~r~estart replay";
-      };
-
-      bool checkForKey( const SDL_KeyboardEvent* key, int modifier, int num )
-      {
-         return ( key->keysym.unicode == 'r' );
-      };
-      
-};
-
-
-class ReplayExit : public GuiFunction
-{
-   public:
-      bool available( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         if ( runreplay.status == 1 || runreplay.status == 10 || runreplay.status == 11 )
-              return true;
-
-         return false;
-      };
-
-      void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         runreplay.status = 100;
-         updateFieldInfo();
-      }
-
-      Surface& getImage( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return IconRepository::getIcon("replay-exit.png");
-      };
-
-      ASCString getName( const MapCoordinate& pos, ContainerBase* subject, int num )
-      {
-         return "e~x~it replay";
-      };
-
-      bool checkForKey( const SDL_KeyboardEvent* key, int modifier, int num )
-      {
-         return ( key->keysym.unicode == 'x' );
-      };
-      
-};
-
 class InternalAmmoTransferDialog : public GuiFunction
 {
    public:
@@ -2911,6 +2697,49 @@ class InternalAmmoTransferDialog : public GuiFunction
       };
 };
 
+class SelfDestructIcon : public GuiFunction
+{
+     static int containeractive;
+   public:
+      bool available( const MapCoordinate& pos, ContainerBase* subject, int num )
+      {
+        tfield* fld = actmap->getField(pos);
+        ContainerBase* c = fld->getContainer();
+        if ( fieldvisiblenow ( fld ) && c ) {
+           SelfDestruct sd;
+           return sd.available(c);
+        }
+        return false;
+      };
+
+      void execute( const MapCoordinate& pos, ContainerBase* subject, int num )
+      {
+          tfield* fld = actmap->getField(pos);
+          if (choice_dlg("do you really want to destruct this unit?","~y~es","~n~o") == 1) {
+            SelfDestruct sd;
+            sd.destruct( fld->getContainer());
+            updateFieldInfo();
+            repaintMap();
+          }
+      }
+
+      Surface& getImage( const MapCoordinate& pos, ContainerBase* subject, int num )
+      {
+         return IconRepository::getIcon("self-destruct.png");
+      };
+
+      bool checkForKey( const SDL_KeyboardEvent* key, int modifier, int num )
+      {
+         return false;
+      };
+      
+      ASCString getName( const MapCoordinate& pos, ContainerBase* subject, int num )
+      {
+         return "self destruct";
+      };
+};
+
+
 
 GuiIconHandler primaryGuiIcons;
 
@@ -2927,15 +2756,6 @@ void registerCargoGuiFunctions( GuiIconHandler& handler )
    // handler.registerUserFunction( new GuiFunctions::Movement() );
 }
 
-void registerReplayGuiFunctions( GuiIconHandler& handler )
-{
-   handler.registerUserFunction( new GuiFunctions::ReplayPlay() );
-   handler.registerUserFunction( new GuiFunctions::ReplayPause() );
-   handler.registerUserFunction( new GuiFunctions::ReplayFaster() );
-   handler.registerUserFunction( new GuiFunctions::ReplaySlower() );
-   handler.registerUserFunction( new GuiFunctions::ReplayRewind() );
-   handler.registerUserFunction( new GuiFunctions::ReplayExit() );
-}
 
 void registerGuiFunctions( GuiIconHandler& handler )
 {
@@ -2968,6 +2788,7 @@ void registerGuiFunctions( GuiIconHandler& handler )
    handler.registerUserFunction( new GuiFunctions::InternalAmmoTransferDialog );
    
    handler.registerUserFunction( new GuiFunctions::EndTurn() );
+   handler.registerUserFunction( new GuiFunctions::SelfDestructIcon() );
    handler.registerUserFunction( new GuiFunctions::Cancel() );
    
 }
