@@ -45,6 +45,7 @@
 #include "loadpcx.h"
 #include "iconrepository.h"
 #include "mainscreenwidget.h"
+#include "sdl/sound.h"
 
 #ifndef karteneditor
  #include "dialogs/attackpanel.h"
@@ -73,6 +74,18 @@ class ContainerInfoLayer : public MapLayer {
                return true;
          return false;
       };
+      
+      bool hasOwnCargo( const ContainerBase* c, int viewingPlayer ) {
+         for ( ContainerBase::Cargo::const_iterator i = c->getCargo().begin(); i != c->getCargo().end(); ++i )
+            if ( *i ) {
+               if ( (*i)->getOwner() == viewingPlayer )
+                  return true;
+               else
+                  if ( hasOwnCargo( *i, viewingPlayer ))
+                     return true;
+            }
+         return false;
+      };
     public: 
       ContainerInfoLayer() : marker( IconRepository::getIcon("fieldcontainermarker.png") ) {};
          
@@ -85,9 +98,13 @@ void ContainerInfoLayer::paintSingleField( const MapRenderer::FieldRenderInfo& f
    if ( fieldInfo.visibility >= visible_ago) {
       if ( fieldInfo.fld->vehicle || (fieldInfo.fld->building && fieldInfo.fld->bdt.test(cbbuildingentry) )) {
          ContainerBase* c = fieldInfo.fld->getContainer();
-         if ( c->getOwner() == fieldInfo.playerView && hasCargo(c) ) 
-            fieldInfo.surface.Blit( marker, pos );
-         
+         if ( hasCargo(c) ) {
+            if ( c->getOwner() == fieldInfo.playerView  ) 
+               fieldInfo.surface.Blit( marker, pos );
+            else
+               if ( hasOwnCargo(c, fieldInfo.playerView  ))
+                  fieldInfo.surface.Blit( marker, pos );
+         }
       }
    }
 }
@@ -870,8 +887,16 @@ void filterQueuedZoomEvents()
 
 bool MapDisplayPG::eventMouseButtonDown (const SDL_MouseButtonEvent *button)
 {
+   MapCoordinate mc = screenPos2mapPos( SPoint(button->x, button->y));
+
    if ( button->type == SDL_MOUSEBUTTONDOWN && button->button == CGameOptions::Instance()->mouse.zoomoutbutton ) {
       changeZoom( 10 );
+   
+      MapCoordinate newpos = screenPos2mapPos( SPoint(button->x, button->y));
+      MapCoordinate newOffset ( offset.x - ( newpos.x - mc.x ), offset.y - ( newpos.y - mc.y ));
+      checkViewPosition( newOffset );
+      offset = newOffset;
+
       viewChanged();
       repaintMap();
       filterQueuedZoomEvents();
@@ -880,6 +905,12 @@ bool MapDisplayPG::eventMouseButtonDown (const SDL_MouseButtonEvent *button)
 
    if ( button->type == SDL_MOUSEBUTTONDOWN && button->button == CGameOptions::Instance()->mouse.zoominbutton ) {
       changeZoom( -10 );
+
+      MapCoordinate newpos = screenPos2mapPos( SPoint(button->x, button->y));
+      MapCoordinate newOffset ( offset.x - ( newpos.x - mc.x ), offset.y - ( newpos.y - mc.y ));
+      checkViewPosition( newOffset );
+      offset = newOffset;
+
       viewChanged();
       repaintMap();
       filterQueuedZoomEvents();
@@ -887,7 +918,6 @@ bool MapDisplayPG::eventMouseButtonDown (const SDL_MouseButtonEvent *button)
    }
 
 
-   MapCoordinate mc = screenPos2mapPos( SPoint(button->x, button->y));
    if ( !(mc.valid() && mc.x < actmap->xsize && mc.y < actmap->ysize ))
       return false;
 
@@ -1355,7 +1385,7 @@ void MapDisplayPG::displayAddons( Surface& surf, int pass)
    if( additionalUnit ) 
       if ( pass == bitmappedHeight2pass( additionalUnit->height ) )  {
          SPoint p = mapViewPos2internalPos( additionalUnit->getPosition() - offset );
-         if ( p.x >= 0 && p.y >= 0 && p.x + fieldsizex < surf.w() && p.y + fieldsizey < surf.h() )
+         if ( p.x >= 0 && p.y >= 0 && p.x + fieldsizex + ContainerBase::calcShadowDist(log2(chsatellit)) < surf.w() && p.y + fieldsizey  + ContainerBase::calcShadowDist(log2(chsatellit)) < surf.h() )
             additionalUnit->paint( surf, p, false, -1 );
       }
 
@@ -1677,170 +1707,6 @@ void MapDisplayPG::Cursor::goTo( const MapCoordinate& position )
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-class PG_MapDisplay : public MapDisplayInterface {
-           MapDisplayPG* mapDisplayWidget;
-         public:
-           PG_MapDisplay( MapDisplayPG* mapDisplayWidget_ ) : mapDisplayWidget( mapDisplayWidget_ ) {};
-
-           int displayMovingUnit ( const MapCoordinate3D& start, const MapCoordinate3D& dest, Vehicle* vehicle, int fieldnum, int totalmove, SoundStartCallback soundStart );
-           void deleteVehicle ( Vehicle* vehicle ) {};
-           void displayMap ( void );
-           void displayMap ( Vehicle* vehicle );
-           void displayPosition ( int x, int y );
-           void resetMovement ( void ) {};
-           void startAction ( void );
-           void stopAction ( void );
-           void cursor_goto ( const MapCoordinate& pos );
-           void displayActionCursor ( int x1, int y1, int x2, int y2 ) {};
-           void removeActionCursor ( void ) {
-              mapDisplayWidget->cursor.invisible = 1;
-           };
-           void updateDashboard ();
-           void repaintDisplay ();
-           void setTempView( bool view ) { tempsvisible = view; };
-           void showBattle( tfight& battle );
-};
-
-
-
-int  PG_MapDisplay :: displayMovingUnit ( const MapCoordinate3D& start, const MapCoordinate3D& dest, Vehicle* vehicle, int fieldnum, int totalmove, SoundStartCallback soundStart )
-{
-   if ( actmap->getPlayerView() == -2 )
-      return 0;
-
-   MapCoordinate3D newstart = start;
-   MapCoordinate3D newdest = dest;
-   
-   if ( newdest.getNumericalHeight() == -1 )
-      newdest.setNumericalHeight( newstart.getNumericalHeight() );
-   else
-      if ( newstart.getNumericalHeight() == -1 )
-         newstart.setNumericalHeight( newdest.getNumericalHeight() );
-
-   if ( newstart.getNumericalHeight() < newdest.getNumericalHeight() ) {
-      if ( fieldnum+1 < totalmove )
-         newdest.setNumericalHeight( newstart.getNumericalHeight() );
-   }
-   
-   if ( newstart.getNumericalHeight() > newdest.getNumericalHeight() ) {
-      if ( fieldnum > 0  )
-         newstart.setNumericalHeight( newdest.getNumericalHeight() );
-   }
-   
-   tfield* fld1 = actmap->getField ( start );
-   int view1 = fieldVisibility ( fld1, actmap->getPlayerView(), actmap );
-
-   tfield* fld2 = actmap->getField ( dest );
-   int view2 = fieldVisibility ( fld2, actmap->getPlayerView(), actmap );
-
-   bool shareView;
-   if ( actmap->getPlayerView() >= 0)
-      shareView = actmap->player[actmap->getPlayerView()].diplomacy.sharesView( vehicle->getOwner() );
-   else
-      shareView = false;
-
-   if (  (view1 >= visible_now  ||  view2 >= visible_now ) || ( vehicle->getOwner() == actmap->getPlayerView() ) || shareView || actmap->getPlayerView() == -1 )
-      if ( ((vehicle->height >= chschwimmend) && (vehicle->height <= chhochfliegend)) || (( view1 == visible_all) || ( view2 == visible_all )) || ( actmap->actplayer == actmap->getPlayerView() ) || shareView || actmap->getPlayerView() == -1 ) {
-         soundStart( 1 );
-         mapDisplayWidget->displayUnitMovement( actmap, vehicle, newstart, newdest );
-      }
-
-
-   int result = 0;
-   if (view1 >= visible_now )
-      result +=1;
-
-   if ( view2 >= visible_now )
-      result +=2;
-
-   return result;
-}
-
-void PG_MapDisplay :: showBattle( tfight& battle )
-{
-#ifndef karteneditor
-   showAttackAnimation( battle, actmap );
-#endif
-}
-
-
-void PG_MapDisplay :: displayMap ( void )
-{
-   ::repaintMap();
-}
-
-void PG_MapDisplay :: cursor_goto ( const MapCoordinate& pos )
-{
-   mapDisplayWidget->cursor.goTo( pos );
-}
-
-
-void PG_MapDisplay :: displayMap ( Vehicle* vehicle )
-{
-   mapDisplayWidget->registerAdditionalUnit( vehicle ); 
-   ::repaintMap();
-   mapDisplayWidget->registerAdditionalUnit( NULL ); 
-}
-
-
-void PG_MapDisplay :: displayPosition ( int x, int y )
-{
-   if ( !mapDisplayWidget->fieldInView( MapCoordinate(x,y) ))
-      mapDisplayWidget->centerOnField( MapCoordinate(x,y) );
-   else
-      mapDisplayWidget->Update();
-}
-
-
-void PG_MapDisplay :: startAction ( void )
-{
-}
-
-void PG_MapDisplay :: stopAction ( void )
-{
-}
-
-void PG_MapDisplay :: updateDashboard ( void )
-{
-   updateFieldInfo();
-}
-
-void PG_MapDisplay :: repaintDisplay ()
-{
-   ::repaintDisplay();
-}
-
-    
-
-MapDisplayInterface& getDefaultMapDisplay()
-{
-   static PG_MapDisplay* mapDisplay = NULL;
-   if ( !mapDisplay ) {
-      assert( theGlobalMapDisplay );
-      mapDisplay = new PG_MapDisplay( theGlobalMapDisplay );
-   }   
-   return *mapDisplay;
-}
-
-
 int lockdisplaymap = 0;
 
 
