@@ -36,11 +36,15 @@ ppixelxlattable xlatpictgraytable;
 
 txlattables xlattables;
 tmixbuf *colormixbuf;
-tpixelxlattable bi2asc_color_translation_table;
+char* colormixbufchar;
+// tpixelxlattable bi2asc_color_translation_table;
 
 bool asc_paletteloaded = 0;
 
-char* borland_c_sucks ( void )
+const char* borland_c_sucks ( void )
 {
    return "just some code";
 }
+
+
+
