@@ -326,12 +326,22 @@ void Player :: turnEnds( Player& p )
 {
    if ( &p == this ) {
       sendQueuedMessages();
+
+      if ( !exist() && stat != off ) {
+         stat = off;
+         resetView();
+         resetResearch();
+         resetTribute();
+         resetPassword();
+         email = "";
+         name += " (removed)";
+      }
    }
 }
 
 
 
-DI_Color Player :: getColor()
+DI_Color Player :: getColor() const
 {
    if ( color == DI_Color(0)) {
       switch ( player ) {
@@ -350,6 +360,12 @@ DI_Color Player :: getColor()
       return color;
 }
 
+PlayerColor Player::getPlayerColor() const
+{
+   return PlayerColor(getPosition(), getColor() );
+}
+
+
 ASCString Player :: getName( ) const
 {
    if ( name.length() ) 
@@ -531,3 +547,36 @@ void Player::merge ( Player& secondPlayer )
 
 }
 
+
+void Player::resetView()
+{
+   for ( int x = 0; x < getParentMap()->xsize; x++ )
+      for ( int y = 0; y < getParentMap()->ysize; y++ ) {
+         tfield* fld = getParentMap()->getField(x,y);
+         fld->setVisibility( visible_not, player );
+         if ( fld->resourceview )
+            fld->resourceview->visible &= ~(1<<player);
+      }
+
+}
+void Player::resetResearch()
+{
+   research.clear();
+}
+
+void Player::resetTribute()
+{
+   for ( int j = 0; j< getParentMap()->getPlayerCount(); ++j ) {
+      getParentMap()->tribute.avail[player][j] = Resources();
+      getParentMap()->tribute.avail[j][player]= Resources();
+      getParentMap()->tribute.paid[player][j] = Resources();
+      getParentMap()->tribute.paid[j][player]= Resources();
+      getParentMap()->tribute.payStatusLastTurn[player][j] = Resources();
+      getParentMap()->tribute.payStatusLastTurn[j][player]= Resources();
+   }
+}
+
+void Player::resetPassword()
+{
+   passwordcrc.reset();
+}
