@@ -86,7 +86,8 @@ enum trpl_actions { rpl_attack,
                     rpl_repairUnit3,
                     rpl_transferTribute,
                     rpl_reactionFireOn,
-                    rpl_reactionFireOff };
+                    rpl_reactionFireOff,
+                    rpl_selfdestruct };
 
 extern void logtoreplayinfo ( trpl_actions action, ... );
 
@@ -98,7 +99,7 @@ class trunreplay {
             int movenum;
             void execnextreplaymove ( void );
             GameMap* orgmap;
-            pmemorystream stream;
+            tmemorystream* stream;
             void wait ( int t = ticker );
             void wait ( MapCoordinate pos, int t = ticker );
             void wait ( MapCoordinate pos1, MapCoordinate pos2, int t = ticker );
