@@ -133,7 +133,7 @@
 #include "sdl/sound.h"
 #include "soundList.h"
 #include "turncontrol.h"
-#include "network.h"
+#include "networksupervisor.h"
 
 #include "dialogs/newgame.h"
 #include "dialogs/soundsettings.h"
@@ -147,7 +147,8 @@
 #include "stdio-errorhandler.h"
 #include "widgets/textrenderer.h"
 #include "dialogs/productionanalysis.h"
-
+#include "dialogs/fileselector.h"
+#include "containerbase-functions.h"
 #include "memory-measurement.h"
 
 #ifdef WIN32
@@ -1136,12 +1137,21 @@ void viewMiningPower()
    for ( Player::BuildingList::iterator i = actmap->getCurrentPlayer().buildingList.begin(); i != actmap->getCurrentPlayer().buildingList.end(); ++i )
       if ( (*i)->baseType->hasFunction( ContainerBaseType::MiningStation )) {
          int power;
+         int output;
+         MiningStation miningStation ( *i, true );
          for ( int r = 0; r < 3; ++r )
             if ( (*i)->maxplus.resource(r) ) {
                power = 100 * (*i)->plus.resource(r) / (*i)->maxplus.resource(r) ;
                break;
             }
-         ASCString txt = ASCString::toString(power) + "% " + (*i)->getPosition().toString() + " " + (*i)->baseType->name + "\n";
+            
+         for ( int r = 0; r < 3; ++r )
+            if ( miningStation.getPlus().resource(r) ) {
+               output = miningStation.getPlus().resource(r);
+               break;
+            }
+            
+         ASCString txt = ASCString::toString(output) + " (" + ASCString::toString(power) + "%) " + (*i)->getPosition().toString() + " " + (*i)->baseType->name + "\n";
          info[(*i)->baseType] += txt;
       }
 
@@ -1317,7 +1327,7 @@ void execuseraction2 ( tuseractions action )
                vft.RunModal();
                                };
          break;
-      case ua_showUnitEndurance: showUnitEndurance();
+      case ua_showUnitEndurance:  showUnitEndurance(); 
          break;
          
       case ua_getMemoryFootprint: showMemoryFootprint();
@@ -1610,7 +1620,7 @@ void deployMapPlayingHooks ( GameMap* map )
 
 int main(int argc, char *argv[] )
 {
-   // setenv( "DISPLAY", "192.168.0.61:0", 1 );
+  // setenv( "DISPLAY", "192.168.0.61:0", 1 );
 
    putenv(const_cast<char*>("SDL_VIDEO_CENTERED=1")) ;
 
@@ -1695,6 +1705,7 @@ int main(int argc, char *argv[] )
    
    tspfldloaders::mapLoaded.connect( SigC::slot( deployMapPlayingHooks ));
 
+   PG_FileArchive archive( argv[0] );
    ASC_PG_App app ( "asc2_dlg" );
 
    app.sigAppIdle.connect ( SigC::slot( mainloopidle ));
