@@ -215,7 +215,10 @@ const char*  buildingFunctionTags[24]  =
    "immune_to_mines",
    "jam_only_own_field",
    "MoveDuringReactionFire",
-   "onlyTransMove" 
+   "onlyTransMove",
+   "AutoHarvestObjects",
+   "NoProductionCustomization",
+   "ManualSelfDestruct"
    };
    
    
