@@ -31,6 +31,7 @@
 #include "textfiletags.h"
 #include "textfile_evaluation.h"
 #include "graphics/blitter.h"
+#include "graphics/ColorTransform_PlayerColor.h"
 
 /*
 const char*  cvehiclefunctions[cvehiclefunctionsnum+1]  = {
@@ -127,6 +128,13 @@ Vehicletype :: Vehicletype ( void )
    for ( i = 0; i < 8; i++ )
       aiparam[i] = NULL;
 
+   
+   static const float matrix[] = { 1, 0, 0,
+                                 0, 1, 0,
+                                 0, 0, 1 };
+   
+   productionEfficiency = ResourceMatrix( matrix );
+   
 }
 
 
@@ -951,14 +959,17 @@ void Vehicletype::runTextIO ( PropertyContainer& pc )
    else
       pc.addBool ( "WaitForAttack", wait );
 
-   pc.openBracket( "Tank" );
-   Resources tank;
-   tank.runTextIO ( pc );
-   pc.closeBracket();
-   bi_mode_tank = tank;
-   asc_mode_tank = tank;
+   if ( bi_mode_tank == Resources(0,0,0) && asc_mode_tank == Resources(0,0,0)) {
+	   pc.openBracket( "Tank" );
+	   Resources tank;
+	   tank.runTextIO ( pc );
+	   pc.closeBracket();
+	   bi_mode_tank = tank;
+	   asc_mode_tank = tank;
+   }
+   
    pc.addInteger( "FuelConsumption", fuelConsumption );
-   if ( pc.find("Abilities")) {
+   if ( !pc.find("Features") && pc.isReading() ) {
       int abilities;
       pc.addTagInteger ( "Abilities", abilities, legacyVehicleFunctionNum, vehicleAbilities );
 
@@ -1012,7 +1023,7 @@ void Vehicletype::runTextIO ( PropertyContainer& pc )
    pc.closeBracket();
 
    pc.openBracket ( "Weapons");
-   pc.addInteger("Initiative", initiative );
+   // pc.addInteger("Initiative", initiative );
    pc.addInteger("Number", weapons.count );
    for ( int i = 0; i < weapons.count; i++ ) {
       pc.openBracket ( ASCString("Weapon")+strrr(i) );
@@ -1177,11 +1188,16 @@ BitSet Vehicletype::convertOldFunctions( int abilities, const ASCString& locatio
    return features;
 }
 
-void  Vehicletype::paint ( Surface& s, SPoint pos, int player, int direction ) const
+void  Vehicletype::paint ( Surface& s, SPoint pos, const PlayerColor& player, int direction ) const
 {
    megaBlitter<ColorTransform_PlayerCol,ColorMerger_AlphaOverwrite,SourcePixelSelector_Plain,TargetPixelSelector_All>( getImage(), s, pos, player, nullParam, nullParam, nullParam );
 }
 
+void  Vehicletype::paint ( Surface& s, SPoint pos ) const
+{
+   megaBlitter<ColorTransform_None,ColorMerger_AlphaOverwrite,SourcePixelSelector_Plain,TargetPixelSelector_All>( getImage(), s, pos, nullParam, nullParam, nullParam, nullParam );
+}
+
 
 void SingleWeapon::runTextIO ( PropertyContainer& pc )
 {
